@@ -1,15 +1,16 @@
 #!/bin/sh
 echo 'name: unbounded-delays
-version: 0.1.0.4
-id: unbounded-delays-0.1.0.4-4e0a9db0c4149305eeabb8c8df7d0a03
+version: 0.1.0.5
+id: unbounded-delays-0.1.0.5-c704cbc4d2c5120d0499bed17bf02164
 
 license: BSD3
-copyright: 2011 Bas van Dijk & Roel van Dijk
+copyright: 2011-2012 Bas van Dijk & Roel van Dijk
 maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
             Roel van Dijk <vandijk.roel@gmail.com>
 stability:
 homepage: https://github.com/basvandijk/unbounded-delays
 package-url:
+synopsis: Unbounded thread delays and timeouts
 description: The @threadDelay@ and @timeout@ functions from the @base@ library
              use the bounded @Int@ type for specifying the delay or timeout
              period. This packages provides alternatives which use the
@@ -22,19 +23,20 @@ exposed: True
 exposed-modules: Control.Concurrent.Thread.Delay
                  Control.Concurrent.Timeout
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/unbounded-delays-0.1.0.4
-library-dirs: /usr/local/lib/ghc/unbounded-delays-0.1.0.4
-hs-libraries: HSunbounded-delays-0.1.0.4
+trusted: False
+import-dirs: /usr/local/lib/ghc/unbounded-delays-0.1.0.5
+library-dirs: /usr/local/lib/ghc/unbounded-delays-0.1.0.5
+hs-libraries: HSunbounded-delays-0.1.0.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-unbounded-delays-0.1.0.4/html/unbounded-delays.haddock
-haddock-html: /usr/local/share/doc/hs-unbounded-delays-0.1.0.4/html
+haddock-interfaces: /usr/local/share/doc/hs-unbounded-delays-0.1.0.5/html/unbounded-delays.haddock
+haddock-html: /usr/local/share/doc/hs-unbounded-delays-0.1.0.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
